@@ -23,6 +23,8 @@
 
 #include <config.h>
 
+#include <stdlib.h>
+
 #include <glib/gi18n.h>
 
 #include <gtk/gtkx.h>
@@ -30,9 +32,6 @@
 #include "gsm-fail-whale-dialog.h"
 
 #include "gsm-icon-names.h"
-#include "gsm-manager.h"
-#include "gsm-util.h"
-#include "gsm-shell-extensions.h"
 
 #define GSM_FAIL_WHALE_DIALOG_GET_PRIVATE(o)                                \
         (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_FAIL_WHALE_DIALOG, GsmFailWhaleDialogPrivate))
@@ -41,8 +40,8 @@ struct _GsmFailWhaleDialogPrivate
 {
         gboolean debug_mode;
         gboolean allow_logout;
+        gboolean extensions;
         GdkRectangle geometry;
-        GsmShellExtensions *extensions;
 };
 
 G_DEFINE_TYPE (GsmFailWhaleDialog, gsm_fail_whale_dialog, GTK_TYPE_WINDOW);
@@ -132,11 +131,6 @@ on_screen_size_changed (GdkScreen          *screen,
 static void
 gsm_fail_whale_dialog_finalize (GObject *object)
 {
-        GsmFailWhaleDialog *fail_dialog = GSM_FAIL_WHALE_DIALOG (object);
-        GsmFailWhaleDialogPrivate *priv = fail_dialog->priv;
-
-        g_clear_object (&priv->extensions);
-
         G_OBJECT_CLASS (gsm_fail_whale_dialog_parent_class)->finalize (object);
 }
 
@@ -252,15 +246,21 @@ static void
 on_logout_clicked (GtkWidget          *button,
                    GsmFailWhaleDialog *fail_dialog)
 {
-        if (fail_dialog->priv->debug_mode) {
-                gtk_main_quit ();
-        } else {
-                gsm_manager_logout (gsm_manager_get (),
-                                    GSM_MANAGER_LOGOUT_MODE_FORCE,
-                                    NULL);
-
-                gtk_widget_destroy (GTK_WIDGET (fail_dialog));
+        if (!fail_dialog->priv->debug_mode) {
+                g_spawn_command_line_async ("gnome-session-quit --force", NULL);
         }
+        gtk_main_quit ();
+}
+
+static GtkIconSize
+gsm_util_get_computer_fail_icon_size (void)
+{
+        static GtkIconSize icon_size = 0;
+
+        if (icon_size == 0)
+                icon_size = gtk_icon_size_register ("gnome-session-computer-fail", 128, 128);
+
+        return icon_size;
 }
 
 static void
@@ -281,14 +281,12 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
         gtk_window_set_title (GTK_WINDOW (fail_dialog), "");
         gtk_window_set_icon_name (GTK_WINDOW (fail_dialog), GSM_ICON_COMPUTER_FAIL);
 
-        if (!fail_dialog->priv->debug_mode) {
-                gtk_window_set_skip_taskbar_hint (GTK_WINDOW (fail_dialog), TRUE);
-                gtk_window_set_keep_above (GTK_WINDOW (fail_dialog), TRUE);
-                gtk_window_stick (GTK_WINDOW (fail_dialog));
-                gtk_window_set_position (GTK_WINDOW (fail_dialog), GTK_WIN_POS_CENTER_ALWAYS);
-                /* only works if there is a window manager which is unlikely */
-                gtk_window_fullscreen (GTK_WINDOW (fail_dialog));
-        }
+        gtk_window_set_skip_taskbar_hint (GTK_WINDOW (fail_dialog), TRUE);
+        gtk_window_set_keep_above (GTK_WINDOW (fail_dialog), TRUE);
+        gtk_window_stick (GTK_WINDOW (fail_dialog));
+        gtk_window_set_position (GTK_WINDOW (fail_dialog), GTK_WIN_POS_CENTER_ALWAYS);
+        /* only works if there is a window manager which is unlikely */
+        gtk_window_fullscreen (GTK_WINDOW (fail_dialog));
 
         alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
         gtk_widget_show (alignment);
@@ -313,7 +311,7 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
 
         if (!priv->allow_logout)
                 message_label = gtk_label_new (_("A problem has occurred and the system can't recover. Please contact a system administrator"));
-        else if (priv->extensions != NULL && gsm_shell_extensions_n_extensions (priv->extensions) > 0)
+        else if (priv->extensions)
                 message_label = gtk_label_new (_("A problem has occurred and the system can't recover. All extensions have been disabled as a precaution."));
         else
                 message_label = gtk_label_new (_("A problem has occurred and the system can't recover.\nPlease log out and try again."));
@@ -346,18 +344,29 @@ gsm_fail_whale_dialog_init (GsmFailWhaleDialog *fail_dialog)
         fail_dialog->priv = GSM_FAIL_WHALE_DIALOG_GET_PRIVATE (fail_dialog);
 }
 
-void
-gsm_fail_whale_dialog_we_failed (gboolean            debug_mode,
-                                 gboolean            allow_logout,
-                                 GsmShellExtensions *extensions)
+static gboolean debug_mode = FALSE;
+static gboolean allow_logout = FALSE;
+static gboolean extensions = FALSE;
 
+int main (int argc, char *argv[])
 {
-        static GsmFailWhaleDialog *current_dialog = NULL;
-        GsmFailWhaleDialog        *fail_dialog;
+        GOptionEntry entries[] = {
+                 { "debug", 0, 0, G_OPTION_ARG_NONE, &debug_mode, N_("Enable debugging code"), NULL },
+                 { "allow-logout", 0, 0, G_OPTION_ARG_NONE, &allow_logout, N_("Allow logout"), NULL },
+                 { "extensions", 0, 0, G_OPTION_ARG_NONE, &extensions, N_("Show extension warning"), NULL },
+                { NULL, 0, 0, 0, NULL, NULL, NULL }
+        };
 
-        if (current_dialog != NULL) {
-                return;
-        }
+        GsmFailWhaleDialog        *fail_dialog;
+        GError *error = NULL;
+
+        gtk_init_with_args (&argc, &argv, " - fail whale",
+                            entries, GETTEXT_PACKAGE,
+                            &error);
+         if (error != NULL) {
+                 g_warning ("%s", error->message);
+                 exit (1);
+         }
 
         fail_dialog = g_object_new (GSM_TYPE_FAIL_WHALE_DIALOG, NULL);
         fail_dialog->priv->debug_mode = debug_mode;
@@ -366,12 +375,13 @@ gsm_fail_whale_dialog_we_failed (gboolean            debug_mode,
 
         setup_window (fail_dialog);
 
-        current_dialog = fail_dialog;
-        g_signal_connect (current_dialog,
-                          "destroy",
-                          G_CALLBACK (gtk_widget_destroyed),
-                          &current_dialog);
+        g_signal_connect (fail_dialog, "destroy",
+                          G_CALLBACK (gtk_main_quit), NULL);
 
         gtk_widget_show (GTK_WIDGET (fail_dialog));
+
+        gtk_main ();
+
+        return 0;
 }
 
