@@ -28,7 +28,8 @@
 
 #include <dbus/dbus-glib.h>
 
-#include "gs-idle-monitor.h"
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <libgnome-desktop/gnome-idle-monitor.h>
 
 #include "gsm-presence.h"
 #include "gsm-presence-glue.h"
@@ -45,17 +46,18 @@
 
 struct GsmPresencePrivate
 {
-        guint            status;
-        guint            saved_status;
-        char            *status_text;
-        gboolean         idle_enabled;
-        GSIdleMonitor   *idle_monitor;
-        guint            idle_watch_id;
-        guint            idle_timeout;
-        gboolean         screensaver_active;
-        DBusGConnection *bus_connection;
-        DBusGProxy      *bus_proxy;
-        DBusGProxy      *screensaver_proxy;
+        guint             status;
+        guint             saved_status;
+        char             *status_text;
+        gboolean          idle_enabled;
+        GnomeIdleMonitor *idle_monitor;
+        guint             idle_became_active_id;
+        guint             idle_watch_id;
+        guint             idle_timeout;
+        gboolean          screensaver_active;
+        DBusGConnection  *bus_connection;
+        DBusGProxy       *bus_proxy;
+        DBusGProxy       *screensaver_proxy;
 };
 
 enum {
@@ -136,18 +138,20 @@ set_session_idle (GsmPresence   *presence,
         }
 }
 
-static gboolean
-on_idle_timeout (GSIdleMonitor *monitor,
-                 guint          id,
-                 gboolean       condition,
-                 GsmPresence   *presence)
+static void
+idle_became_idle_cb (GnomeIdleMonitor *idle_monitor,
+                     guint             id,
+                     gpointer          user_data)
 {
-        gboolean handled;
+        GsmPresence *presence = user_data;
+        set_session_idle (presence, TRUE);
+}
 
-        handled = TRUE;
-        set_session_idle (presence, condition);
-
-        return handled;
+static void
+idle_became_active_cb (GnomeIdleMonitor *idle_monitor,
+                       GsmPresence      *presence)
+{
+        set_session_idle (presence, FALSE);
 }
 
 static void
@@ -159,20 +163,29 @@ reset_idle_watch (GsmPresence  *presence)
 
         if (presence->priv->idle_watch_id > 0) {
                 g_debug ("GsmPresence: removing idle watch");
-                gs_idle_monitor_remove_watch (presence->priv->idle_monitor,
-                                              presence->priv->idle_watch_id);
+                gnome_idle_monitor_remove_watch (presence->priv->idle_monitor,
+                                                 presence->priv->idle_watch_id);
                 presence->priv->idle_watch_id = 0;
         }
 
+        if (presence->priv->idle_became_active_id > 0) {
+                g_signal_handler_disconnect (presence->priv->idle_monitor,
+                                             presence->priv->idle_became_active_id);
+                presence->priv->idle_became_active_id = 0;
+        }
+
         if (! presence->priv->screensaver_active
             && presence->priv->idle_enabled
             && presence->priv->idle_timeout > 0) {
                 g_debug ("GsmPresence: adding idle watch");
 
-                presence->priv->idle_watch_id = gs_idle_monitor_add_watch (presence->priv->idle_monitor,
-                                                                           presence->priv->idle_timeout,
-                                                                           (GSIdleMonitorWatchFunc)on_idle_timeout,
-                                                                           presence);
+                presence->priv->idle_watch_id = gnome_idle_monitor_add_watch (presence->priv->idle_monitor,
+                                                                              presence->priv->idle_timeout,
+                                                                              idle_became_idle_cb,
+                                                                              presence,
+                                                                              NULL);
+                presence->priv->idle_became_active_id = g_signal_connect (presence->priv->idle_monitor, "became-active",
+                                                                          G_CALLBACK (idle_became_active_cb), presence);
         }
 }
 
@@ -193,7 +206,7 @@ static void
 on_screensaver_proxy_destroy (GObject     *proxy,
                               GsmPresence *presence)
 {
-        g_warning ("Detected that screensaver has left the bus");
+        g_debug ("Detected that screensaver has left the bus");
 
         presence->priv->screensaver_proxy = NULL;
         presence->priv->screensaver_active = FALSE;
@@ -313,7 +326,7 @@ gsm_presence_init (GsmPresence *presence)
 {
         presence->priv = GSM_PRESENCE_GET_PRIVATE (presence);
 
-        presence->priv->idle_monitor = gs_idle_monitor_new ();
+        presence->priv->idle_monitor = gnome_idle_monitor_new ();
 }
 
 void
@@ -450,8 +463,8 @@ gsm_presence_finalize (GObject *object)
         GsmPresence *presence = (GsmPresence *) object;
 
         if (presence->priv->idle_watch_id > 0) {
-                gs_idle_monitor_remove_watch (presence->priv->idle_monitor,
-                                              presence->priv->idle_watch_id);
+                gnome_idle_monitor_remove_watch (presence->priv->idle_monitor,
+                                                 presence->priv->idle_watch_id);
                 presence->priv->idle_watch_id = 0;
         }
 
