@@ -238,7 +238,6 @@ load_standard_apps (GsmManager *manager,
 
                 autostart_dirs = gsm_util_get_autostart_dirs ();
 
-
                 maybe_load_saved_session_apps (manager);
 
                 for (i = 0; autostart_dirs[i]; i++) {
@@ -255,16 +254,6 @@ load_standard_apps (GsmManager *manager,
         g_debug ("fill: *** Done adding default providers");
 }
 
-static void
-load_override_apps (GsmManager *manager,
-                    char      **override_autostart_dirs)
-{
-        int i;
-        for (i = 0; override_autostart_dirs[i]; i++) {
-                gsm_manager_add_autostart_apps_from_dir (manager, override_autostart_dirs[i]);
-        }
-}
-
 static GKeyFile *
 get_session_keyfile_if_valid (const char *path)
 {
@@ -462,18 +451,12 @@ get_session_keyfile (const char *session,
 
 gboolean
 gsm_session_fill (GsmManager  *manager,
-                  char       **override_autostart_dirs,
                   const char  *session)
 {
         GKeyFile *keyfile;
         gboolean is_fallback;
         char *actual_session;
 
-        if (override_autostart_dirs != NULL) {
-                load_override_apps (manager, override_autostart_dirs);
-                return TRUE;
-        }
-
         keyfile = get_session_keyfile (session, &actual_session, &is_fallback);
 
         if (!keyfile)
