@@ -39,6 +39,8 @@
 #include <dbus/dbus-glib-bindings.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include <libnotify/notify.h>
+
 #include "gdm-log.h"
 
 #include "gsm-util.h"
@@ -46,7 +48,7 @@
 #include "gsm-session-fill.h"
 #include "gsm-store.h"
 #include "gsm-system.h"
-#include "gsm-fail-whale-dialog.h"
+#include "gsm-fail-whale.h"
 
 #define GSM_DBUS_NAME "org.gnome.SessionManager"
 
@@ -157,11 +159,6 @@ acquire_name (void)
                 return FALSE;
         }
 
-        g_signal_connect_swapped (bus_proxy,
-                                  "destroy",
-                                  G_CALLBACK (shutdown_cb),
-                                  NULL);
-
         if (! acquire_name_on_proxy (bus_proxy, GSM_DBUS_NAME) ) {
                 gsm_util_init_error (TRUE,
                                      "%s",
@@ -291,7 +288,7 @@ main (int argc, char **argv)
 
         if (show_version) {
                 g_print ("%s %s\n", argv [0], VERSION);
-                exit (1);
+                exit (0);
         }
 
         if (please_fail) {
@@ -300,6 +297,8 @@ main (int argc, char **argv)
                 exit (1);
         }
 
+        notify_init ("GNOME session manager");
+
         gdm_log_init ();
         gdm_log_set_debug (debug);
 
@@ -332,6 +331,12 @@ main (int argc, char **argv)
 
         manager = gsm_manager_new (client_store, failsafe);
 
+        g_signal_connect_object (bus_proxy,
+                                 "destroy",
+                                 G_CALLBACK (shutdown_cb),
+                                 manager,
+                                 G_CONNECT_SWAPPED);
+
         g_unix_signal_add (SIGTERM, term_or_int_signal_cb, manager);
         g_unix_signal_add (SIGINT, term_or_int_signal_cb, manager);
         g_unix_signal_add (SIGUSR1, sigusr1_cb, manager);
